@@ -104,11 +104,11 @@ def run(testrun_id, git_pass, wait_time,env):
     else:
         profile='prod'
     try: 
-        if os.environ["USER_ID"] and os.environ["CLIENT_ID"] and os.environ["CLIENT_SECRET_ID"]:
+        if "USER_ID" in os.environ and "CLIENT_ID" in os.environ and "CLIENT_SECRET_ID" in os.environ:
             user_id = os.environ["USER_ID"]
             client_id = os.environ["CLIENT_ID"]
             client_secret_id=os.environ["CLIENT_SECRET_ID"]
-        else:     
+        else:
             file_path =os.path.join( os.path.expanduser('~'),(".aitest/{}".format(profile)),"configure" )
             file = open(file_path,"r")
             content = file.read()
@@ -241,12 +241,12 @@ def status(testrun_id,env):
         profile='dev'
     else:
         profile='prod'
-    try: 
-        if os.environ["USER_ID"] and os.environ["CLIENT_ID"] and os.environ["CLIENT_SECRET_ID"]:
+    try:
+        if "USER_ID" in os.environ and "CLIENT_ID" in os.environ and "CLIENT_SECRET_ID" in os.environ:
             user_id = os.environ["USER_ID"]
             client_id = os.environ["CLIENT_ID"]
             client_secret_id=os.environ["CLIENT_SECRET_ID"]
-        else:     
+        else:
             file_path =os.path.join( os.path.expanduser('~'),(".aitest/{}".format(profile)),"configure" )
             file = open(file_path,"r")
             content = file.read()
